@@ -23,7 +23,6 @@ from cStringIO import (
     StringIO,
     )
 import os
-import posix
 import shutil
 import stat
 import struct
@@ -176,7 +175,7 @@ class WriteCacheTimeTests(TestCase):
 class IndexEntryFromStatTests(TestCase):
 
     def test_simple(self):
-        st = posix.stat_result((16877, 131078, 64769L,
+        st = os.stat_result((16877, 131078, 64769L,
                 154, 1000, 1000, 12288,
                 1323629595, 1324180496, 1324180496))
         entry = index_entry_from_stat(st, "22" * 20, 0)
@@ -185,7 +184,25 @@ class IndexEntryFromStatTests(TestCase):
             1324180496,
             64769L,
             131078,
-            16877,
+            16384,
+            1000,
+            1000,
+            12288,
+            '2222222222222222222222222222222222222222',
+            0))
+
+    def test_override_mode(self):
+        st = os.stat_result((stat.S_IFREG + 0644, 131078, 64769L,
+                154, 1000, 1000, 12288,
+                1323629595, 1324180496, 1324180496))
+        entry = index_entry_from_stat(st, "22" * 20, 0,
+                mode=stat.S_IFREG + 0755)
+        self.assertEquals(entry, (
+            1324180496,
+            1324180496,
+            64769L,
+            131078,
+            33261,
             1000,
             1000,
             12288,
